## 任务类型(Task Type)
故障根因诊断。

## 任务描述(Task Description)
根据事件识别输出的事件信息和初步定界分析、初步根因分析、初步影响分析等信息，进行故障事件的根因定位，输出根因定位信息及建议处理方案。

## 任务目标(Task Target)
{{任务目标}}（必选）
要求：完成故障事件的根因定位，输出专业根因定位信息、故障根因专业分类、故障根因详情、远程处置方案、现场抢修方案及业务影响分析。

## 任务上下文(Task Context)
{{任务上下文}}（必选）
要求：定义故障根因诊断任务的请求参数。

任务ID：请求任务ID，作为一次任务的唯一标识，可以是雪花算法生成。必选。样例：1111111876

请求任务时间：请求任务时间。必选。样例：2026-04-20 15:36:22

事件告警列表：可能存在多组数据。必选。

事件告警列表中每条事件包含以下字段：
- 事件流水号：故障事件流水号。必选。样例：1856365516_2839324485_2130908106_4130674041
- 事件标准化名称：事件标题名称。必选。样例：5G基站退服事件
- 事件关联的告警厂家内部流水号：事件关联的告警流水号。必选。样例：12321112
- 事件关联的告警传输专业扩展流水号：事件关联告警是传输专业告警，则有一个传输告警流水号，用于给传输工作台使用。必选
- 事件关联主告警网管系统内唯一标识：事件关联告警在网管系统内约定的唯一标识，上下游系统都用这个标识告警。必选。样例：0108-007-012-10-000003
- 事件关联告警标题：事件关联的告警的标题。必选。样例：gNodeB退服告警
- 事件产生时间：事件开始时间。必选。样例：2026-03-02 08:40:44
- 告警级别：告警级别，一级告警（Critical）、二级告警（Major）、三级告警（Minor）、四级告警（Warning），数字越小越严重。必选。样例：Major
- 设备类型：设备类型名称。必选。样例：GNodeB
- 设备厂家：设别厂家名称。必选。样例：华为
- 省份名称：省份名称。必选。样例：福建省
- 地市名称：地市名称。必选。样例：泉州市
- 区县名称：区县名称。可选。样例：惠安县
- 设备制式：设备制式。可选。样例：5G
- 网元ID：基站ID，无线工作台用。可选。样例：2148660
- 网元名称：网元名称。必选。样例：泉州惠安-惠安张坂玉山灯杆G-HRHH
- 告警逻辑分类：告警逻辑分类编码。可选。样例：1110
- 电路号：用于给传输工作台智能体做关联分析。可选。样例：泉州惠安张坂惠南联兴-泉州惠安局楼10GE1097086NR
- 客户名称：客户名称。可选
- 客户编号：客户编号。可选
- 机房信息：用于给动力工作台智能体做关联分析。可选。样例：泉州惠安张坂玉山一楼自建机房
- 网元ip：网元IP地址。可选
- 工程类型：工程类型标识。可选
- 工程开始时间：工程开始时间。可选
- 工程结束时间：工程结束时间。可选

完整请求样例：
故障根因诊断任务请求包含任务ID为1111111876，请求任务时间为2026-04-20 15:36:22，事件告警列表包含一条事件，该事件的内容如下：
- **事件 1**
  - 事件流水号: 1856365516_2839324485_2130908106_4130674041
  - 事件标准化名称: 5G基站退服事件
  - 事件关联的告警厂家内部流水号: 12321112
  - 事件关联主告警网管系统内唯一标识: 0108-007-012-10-000003
  - 事件关联告警标题: gNodeB退服告警
  - 事件产生时间: 2026-03-02 08:40:44
  - 告警级别: Major
  - 设备类型: GNodeB
  - 设备厂家: 华为
  - 省份名称: 福建省
  - 地市名称: 泉州市
  - 区县名称: 惠安县
  - 设备制式: 5G
  - 网元ID: 2148660
  - 网元名称: 泉州惠安-惠安张坂玉山灯杆G-HRHH
  - 告警逻辑分类: 1110
  - 电路号: 泉州惠安张坂惠南联兴-泉州惠安局楼10GE1097086NR
  - 机房信息: 泉州惠安张坂玉山一楼自建机房

## 预期输出(Expected Output)
{{预期输出}}（可选）

要求：通过TextPart返回故障诊断结果。

任务ID：请求任务ID，作为一次任务的唯一标识。必选。样例：1111111876

请求任务时间：请求任务时间。必选。样例：2026-04-20 15:36:22

调用方标识：调用方系统标识，枚举值为传输工作台、无线工作台、动力工作台、核心网工作台、IP工作台。必选。样例：传输工作台

接口调用结果：成功、失败。必选。样例：成功

结果描述：执行结果的描述信息。可选。样例：执行成功

诊断结果列表：程序层面非正常执行返回null。可选。

诊断结果列表中每条事件包含以下字段：
- 事件流水号：事件流水号，作为关联请求事件的唯一标识。必选。样例：1856365516_2839324485_2130908106_4130674041
- 事件根因定位业务结果返回码：枚举值为定位成功（代表定位信息及建议处理方案及影响分析）、驳回（代表定位非本专业原因）、定位失败（代表存在其它问题）、其它。必选。样例：定位成功
- 结果描述：status为驳回或定位失败时必选，描述原因。可选
- 专业根因定位信息：专业根因定位信息。必选
- 根因生成时间：根因生成时间。必选。样例：2026-4-14 8:30:22
- 故障根因专业：枚举值为无线接入网、核心网、数据网、传输网、动环、其它。必选。样例：无线接入网
- 故障根因分类：故障根因分类。必选。样例：无线接入网-软件及数据配置故障
- 故障根因网元ID：多个用英文逗号分隔。可选。样例：UUID:2313124123
- 故障根因网元名称：多个用英文逗号分隔。必选。样例：10378-福州福清莲峰-ZX-PTN-1
- 故障根因网元类型：多个用英文逗号分隔。必选。样例：PTN
- 故障根因告警ID：接收到故障系统中的alarmFP，多个用英文逗号分隔。可选。样例：1856365516_2839324485_2130908106_4130674041
- 定位分析过程：按步骤输出根因定位分析的依据和过程。必选。样例：1.告警核查：XXX；2.设备状态核查：XXX；3.关联验证：XXX
- 根因定位结论：故障根因详情描述。必选。样例：传输链路中断导致
- 远程处置方案说明：包含业务保活、自修复等远程方案。必选。样例：1）业务保活：XXXX 2）自修复：XXXX
- 现场抢修方案说明：现场抢修方案说明。必选。样例：一、需要准备的备件及工具：XXXX 二、处置流程及环节: 步骤一：XXX 步骤二：XXX
- 业务影响生成时间：业务影响生成时间。必选。样例：2026-4-14 8:30:32
- 网络影响说明：网络影响说明，无则写无。可选。样例：如影响XX设备
- 业务影响说明：业务影响说明。必选。样例：影响业务类型：5G上网业务、5G语音业务 影响常驻用户数：215 影响在线用户数：26 影响流量：5.1GB 影响话务量：1.31ERL 影响业务时长：0.2小时 站点级别：重保站点 影响小区：重保小区3个，普通小区3个
- 补充说明：补充说明。可选

完整响应样例：
故障根因诊断任务响应包含任务ID为1111111876，请求任务时间为2026-04-20 15:36:22，调用方标识为传输工作台，接口调用结果为成功，结果描述为执行成功，诊断结果列表包含一条事件，该事件的内容如下：
- **事件 1**
  - 事件流水号: 1856365516_2839324485_2130908106_4130674041
  - 事件根因定位业务结果返回码: 定位成功
  - 根因生成时间: 2026-4-14 8:30:22
  - 故障根因专业: 无线接入网
  - 故障根因分类: 无线接入网-软件及数据配置故障
  - 故障根因网元ID: UUID:2313124123
  - 故障根因网元名称: 10378-福州福清莲峰-ZX-PTN-1
  - 故障根因网元类型: PTN
  - 故障根因告警ID: 1856365516_2839324485_2130908106_4130674041
  - 定位分析过程: 1.告警核查：XXX；2.设备状态核查：XXX；3.关联验证：XXX
  - 根因定位结论: 传输链路中断导致
  - 远程处置方案说明: 1）业务保活：XXXX 2）自修复：XXXX
  - 现场抢修方案说明: 一、需要准备的备件及工具：XXXX 二、处置流程及环节: 步骤一：XXX 步骤二：XXX
  - 业务影响生成时间: 2026-4-14 8:30:32
  - 网络影响说明: 如影响XX设备
  - 业务影响说明: 影响业务类型：5G上网业务、5G语音业务 影响常驻用户数：215 影响在线用户数：26 影响流量：5.1GB 影响话务量：1.31ERL 影响业务时长：0.2小时 站点级别：重保站点 影响小区：重保小区3个，普通小区3个